libname ch8 "."; *The "." sets the default directory to be the current SAS folder;
*The directory can be changed by clicking on the disk icon in the lower right hand corner of the SAS GUI;
*Make sure that the dyads.sas7bdat dataset is copied to this folder;
run;

****************************************************************************************************;
*Figure 8.4: Panel plots of time course for 25 of 100 dyads (obtained by choosing every fourth dyad);
****************************************************************************************************;
data select25;
set ch8.dyads;
if coupleid =	1 or coupleid = 5 or coupleid = 9 or coupleid= 13 or coupleid=17 or coupleid=21
or coupleid =	25 or coupleid = 29 or coupleid = 33 or coupleid= 37 or coupleid=41 or coupleid=45
or coupleid =	49 or coupleid = 53 or coupleid = 57 or coupleid= 61 or coupleid=65 or coupleid=69
or coupleid =	73 or coupleid = 77 or coupleid = 81 or coupleid= 85 or coupleid=89 or coupleid=93
or coupleid=97;

*Create male-specific and female-specific time and relationship dissatisfaction variables;
*These are needed to create Figure 8.4;
if male=0 then ftime=time;
if male=0 then freldis=reldis;
if male=1 then mtime=time;
if male=1 then mreldis=reldis;
run;

goptions reset=all;
ods graphics/reset;
options nodate nonumber center;
run;
ods graphics on/antialiasmax=40200 height=14in width=14in;
ods pdf style=journal dpi=300 file="Figure-8-point-4.pdf";
run;

*Create Figure 8.4 using PROC SGPANEL;
proc sgpanel data=select25  CYCLEATTRS;
 panelby coupleid/columns=5 rows=5 novarname;
 series x = ftime y = freldis / LINEATTRS = (pattern = 1 color=black thickness=2.0) legendlabel="Females";
 series x = mtime y = mreldis / LINEATTRS = (pattern = 1 color=grey thickness=2.0) legendlabel="Males";
 rowaxis min=1 max=9 label='Relationship Dissatisfaction'; *values=(0, 4, 8);
 colaxis label='Time';
run;
ods pdf close;
ods graphics off;
run;
****************************************************************************************************;


****************************************************************************************************;
*Table 8.1 and Table 1 (p. 169): PROC MIXED causal process model for distinguishable dyads;
****************************************************************************************************;
proc mixed data=ch8.dyads covtest method=reml cl;
class coupleid gender time;
model reldis=male female male*time7c female*time7c male*wrkstrscw female*wrkstrscw
                          male*wrkstrscb female*wrkstrscb/noint s cl outpred=cpred ddf=98,98,99,99,99,99,98,98;
random male female male*wrkstrscw female*wrkstrscw/subject=coupleid type=un s g gcorr;
repeated gender time /subject=coupleid type=un@ar(1);
ods exclude SolutionR;
ods output SolutionR = crandpred;
run;

*Run to compare with SPSS & R: Repated statement has ar(1) errors within each partner;
proc mixed data=ch8.dyads covtest method=reml cl;
class coupleid gender time;
model reldis=male female male*time7c female*time7c male*wrkstrscw female*wrkstrscw
                          male*wrkstrscb female*wrkstrscb/noint s cl outpred=cpred ddf=98,98,99,99,99,99,98,98;
random male female male*wrkstrscw female*wrkstrscw/subject=coupleid type=un s g gcorr;
repeated time /subject=coupleid*gender type=ar(1);
ods exclude SolutionR;
ods output SolutionR = crandpred;
run;


*Run to compare with Mplus: ML instead of REML estimation;
proc mixed data=ch8.dyads covtest method=ml cl;
class coupleid gender time;
model reldis=male female male*time7c female*time7c male*wrkstrscw female*wrkstrscw
                          male*wrkstrscb female*wrkstrscb/noint s cl outpred=cpred ddf=98,98,99,99,99,99,98,98;
random male female male*wrkstrscw female*wrkstrscw/subject=coupleid type=un s g gcorr;
repeated gender time /subject=coupleid type=un@ar(1);
ods exclude SolutionR;
run;
****************************************************************************************************;

****************************************************************************************************;
*Figure 8.5: Panel plots with raw data, predicted values and confidence limits for 25 of 100 dyads;
****************************************************************************************************;

*For plotting: Sort data by level of work stressors (within person within dyad);
proc sort data=cpred;
by coupleid male wrkstrs;
run;

*Female partners;
*To simplify plotting, subtract time effect from predicted values;
data fcnew;
set cpred;
if male = 0;
pred1=pred+0.02483*time7c;
upper1=upper+0.02483*time7c;
lower1=lower+0.02483*time7c;
run;

*Male partners;
data mcnew;
set cpred;
if male = 1;
pred1=pred-0.01150*time7c;
upper1=upper-0.01150*time7c;
lower1=lower-0.01150*time7c;
run;

*Create male-specific and female-specific time and relationship dissatisfaction variables;
data cnew;
set fcnew mcnew;
if male=0 then ftime=time;
if male=0 then frelconf=reldis;
if male=1 then mtime=time;
if male=1 then mrelconf=reldis;
if male=0 then gencat= 'Female Partners';
if male=0 then fpred1=pred1;
if male=0 then fwrkstrs=wrkstrs;
if male=0 then fupper1=upper1;
if male=0 then flower1=lower1;
if male=1 then gencat= 'Male Partners';
if male=1 then mpred1=pred1;
if male=1 then mwrkstrs=wrkstrs;
if male=1 then mupper1=upper1;
if male=1 then mlower1=lower1;
*Create predicted vaues for the average male partner and the average female partner;
*Note because work stressors are centered at 2.99 stressors, for plotting 
it is necessary to subtract this effect from the intercepts for males and females;
if male=0 then pred1mean=4.6475 + 0.1599*wrkstrs -0.1599*2.9904762;
if male=1 then pred1mean=5.0857 + 0.1091*wrkstrs -0.1091*2.9904762;
run;

*For plotting, create dataset with 25 of 100 couples;
data select25a;
set cnew;
if coupleid =	1 or coupleid = 5 or coupleid = 9 or coupleid= 13 or coupleid=17 or coupleid=21
or coupleid =	25 or coupleid = 29 or coupleid = 33 or coupleid= 37 or coupleid=41 or coupleid=45
or coupleid =	49 or coupleid = 53 or coupleid = 57 or coupleid= 61 or coupleid=65 or coupleid=69
or coupleid =	73 or coupleid = 77 or coupleid = 81 or coupleid= 85 or coupleid=89 or coupleid=93
or coupleid=97;
run;

goptions reset=all;
ods graphics/reset;
options nodate nonumber center;
run;
ods graphics on/antialiasmax=40200 height=14in width=14in;
ods pdf style=journal dpi=300 file="Figure-8-point-5.pdff";
run;

*Create Figure 8.5 using PROC SGPANEL;
proc sgpanel data=select25a NOAUTOLEGEND;
 panelby coupleid/columns=5 rows=5 novarname;
 series x = fwrkstrs y = fpred1 /LINEATTRS = (color = black thickness=2);
 band x=fwrkstrs upper=fupper1 lower=flower1/ outline;
 scatter x = fwrkstrs y = frelconf/MARKERATTRS = (symbol=circlefilled color = black size=11px);
 series x = mwrkstrs y = mpred1 /LINEATTRS = (color = grey thickness=2.5);
 band x=mwrkstrs upper=mupper1 lower=mlower1;
 scatter x = mwrkstrs y = mrelconf/MARKERATTRS = (symbol=circle color = black size=11px);
 rowaxis min=2 max=8 label='Relationship Dissatisfaction';
 colaxis min=1 max=5 label='Work Stressors';
run;
ods pdf close;
run;
ods graphics off;
run;
****************************************************************************************************;

****************************************************************************************************;
*Figure 8.6 and Figure 1 (p. 168): Use SGPANEL to create
spaghetti plot of work stressors and predicted relationship dissatisfaction;
****************************************************************************************************;

goptions reset=all;
ods graphics/reset;
options nodate nonumber center;
run;
ods graphics on/antialiasmax=40200 height=8in width=10in;
ods pdf style=journal dpi=300 file="Figure-8-point-6.pdf";
run;

*Create Figure 8.6 using PROC SGPANEL;
proc sgpanel data=cnew noautolegend;
panelby gencat/novarname;
series x=wrkstrs y=pred1/group=coupleid LINEATTRS = (pattern = 1 color = black thickness=1.5);
series x=wrkstrs y=pred1mean/LINEATTRS = (pattern = 1 color = black thickness=9);
rowaxis min=2 max=7 label='Relationship Dissatisfaction';
colaxis min=1 max=5 label='Work Stressors';
run;
ods pdf close;
ods graphics off;
run;
****************************************************************************************************;
